@@ -1,14 +1,10 @@
-# -*- coding: utf-8 -*-
 # SPDX-License-Identifier: ISC
 # Copyright (c) Amadeusz Zolnowski <aidecoe@aidecoe.name>
 
-from __future__ import print_function, absolute_import, unicode_literals
-
 import re
 
-from ..utils import filter_compat
-from .BaseFilter import Filter
-from ..NotmuchSettings import notmuch_settings
+from afew.filters.BaseFilter import Filter
+from afew.NotmuchSettings import notmuch_settings
 
 
 class MeFilter(Filter):
@@ -21,8 +17,8 @@ class MeFilter(Filter):
         my_addresses = set()
         my_addresses.add(notmuch_settings.get('user', 'primary_email'))
         if notmuch_settings.has_option('user', 'other_email'):
-            other_emails = notmuch_settings.get('user', 'other_email').split(';')
-            my_addresses.update(filter_compat(None, other_emails))
+            for other_email in notmuch_settings.get('user', 'other_email').split(';'):
+                my_addresses.add(other_email)
 
         self.query = ' OR '.join('to:"%s"' % address
                                  for address in my_addresses)
