@@ -1,14 +1,10 @@
-# -*- coding: utf-8 -*-
 # SPDX-License-Identifier: ISC
 # Copyright (c) Justus Winter <4winter@informatik.uni-hamburg.de>
 
-from __future__ import print_function, absolute_import, unicode_literals
-
 import re
 
-from ..utils import filter_compat
-from .BaseFilter import Filter
-from ..NotmuchSettings import notmuch_settings
+from afew.filters.BaseFilter import Filter
+from afew.NotmuchSettings import notmuch_settings
 
 
 class SentMailsFilter(Filter):
@@ -21,14 +17,15 @@ class SentMailsFilter(Filter):
         my_addresses = set()
         my_addresses.add(notmuch_settings.get('user', 'primary_email'))
         if notmuch_settings.has_option('user', 'other_email'):
-            my_addresses.update(filter_compat(None, notmuch_settings.get('user', 'other_email').split(';')))
+            for other_email in notmuch_settings.get('user', 'other_email').split(';'):
+                my_addresses.add(other_email)
 
         self.query = (
-            '(' +
-            ' OR '.join('from:"%s"' % address for address in my_addresses)
-            + ') AND NOT (' +
-            ' OR '.join('to:"%s"'   % address for address in my_addresses)
-            + ')'
+                '(' +
+                ' OR '.join('from:"%s"' % address for address in my_addresses)
+                + ') AND NOT (' +
+                ' OR '.join('to:"%s"' % address for address in my_addresses)
+                + ')'
         )
 
         self.sent_tag = sent_tag
@@ -36,7 +33,6 @@ class SentMailsFilter(Filter):
         if to_transforms:
             self.__email_to_tags = self.__build_email_to_tags(to_transforms)
 
-
     def handle_message(self, message):
         if self.sent_tag:
             self.add_tags(message, self.sent_tag)
@@ -48,7 +44,6 @@ class SentMailsFilter(Filter):
                 else:
                     break
 
-
     def __build_email_to_tags(self, to_transforms):
         email_to_tags = dict()
 
@@ -62,7 +57,6 @@ class SentMailsFilter(Filter):
 
         return email_to_tags
 
-
     def __get_bare_email(self, email):
         if not '<' in email:
             return email
@@ -70,7 +64,6 @@ class SentMailsFilter(Filter):
             match = self._bare_email_re.search(email)
             return match.group('email')
 
-
     def __pick_tags(self, email):
         if email in self.__email_to_tags:
             tags = self.__email_to_tags[email]
@@ -78,6 +71,6 @@ class SentMailsFilter(Filter):
                 return tags
             else:
                 user_part, domain_part = email.split('@')
-                return (user_part, )
+                return (user_part,)
 
         return tuple()
